<?php

namespace Drupal\vat_number\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Field\WidgetBase;
use Drupal\vat_number\Controller\VATNumberController;

/**
 * Plugin implementation of the 'field_example_colorpicker' widget.
 *
 * @FieldWidget(
 *   id = "vat_widget",
 *   module = "vat_number",
 *   label = @Translation("VAT Number"),
 *   field_types = {
 *     "vat_number"
 *   }
 * )
 */
class VATNumberWidget extends WidgetBase {

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {
    $element += [
      '#type' => 'textfield',
      '#element_validate' => [
        [$this, 'validate'],
      ],
    ];

    return ['value' => $element];
  }

  /**
   * Validate the fields and check if the vat number is valid.
   */
  public function validate($element, FormStateInterface $form_state) {
    $value = $element['#value'];
    if (!empty($value)) {

      // Include the VAT Controller.
      $vatController = new VATNumberController($value);

      // Validate VAT number.
      $valid = $vatController->check();
      if (!$valid['status']) {
        $form_state->setError($element, $valid['message']);
      }
    }
  }

}
